import tempfile
import unittest
import unittest.mock
import contextlib

import pydeduplines


class PyDeduplinesTestCase(
    unittest.TestCase,
):
    def test_pydeduplines(
        self,
    ):
        with contextlib.ExitStack() as stack:
            test_input_file_one = stack.enter_context(tempfile.NamedTemporaryFile('w'))
            test_input_file_two = stack.enter_context(tempfile.NamedTemporaryFile('w'))
            test_output_file_one = stack.enter_context(tempfile.NamedTemporaryFile('r'))
            test_output_file_two = stack.enter_context(tempfile.NamedTemporaryFile('r'))

            test_input_file_one.file.write(
                'line1\n'
                'line2\n'
                'line3\n'
                'line1\n'
                'line3\n'
                'line4\n'
                'line1\n'
            )
            test_input_file_one.file.flush()
            test_input_file_two.file.write(
                'line1\n'
                'line2\n'
                'line3\n'
                'line5\n'
                'line1\n'
                'line3\n'
                'line4\n'
                'line1\n'
            )
            test_input_file_two.file.flush()

            pydeduplines.deduplicate_lines(
                input_files_paths=[
                    test_input_file_one.name,
                ],
                output_file_path=test_output_file_one.name,
            )

            deduped_file_data = test_output_file_one.read()
            self.assertEqual(
                first=deduped_file_data,
                second=(
                    'line1\n'
                    'line2\n'
                    'line3\n'
                    'line4\n'
                ),
            )

            pydeduplines.deduplicate_lines(
                input_files_paths=[
                    test_input_file_one.name,
                    test_input_file_two.name,
                ],
                output_file_path=test_output_file_two.name,
            )

            deduped_file_data = test_output_file_two.read()
            self.assertEqual(
                first=deduped_file_data,
                second=(
                    'line1\n'
                    'line2\n'
                    'line3\n'
                    'line4\n'
                    'line5\n'
                ),
            )



import setuptools
import os
import glob


setuptools.setup(
    name='PyDeduplines',
    version='0.1.4',
    author='Gal Ben David',
    author_email='gal@intsights.com',
    url='https://github.com/intsights/PyDeduplines',
    project_urls={
        'Source': 'https://github.com/intsights/PyDeduplines',
    },
    license='MIT',
    description='Python library for a duplicate lines removal written in C++',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    keywords='duplicates lines mimalloc hashmap hashset sort uniq unique c++',
    python_requires='>=3.6',
    zip_safe=False,
    package_data={},
    include_package_data=True,
    ext_modules=[
        setuptools.Extension(
            name='pydeduplines',
            sources=glob.glob(
                pathname=os.path.join(
                    'src',
                    'pydeduplines.cpp',
                ),
            ),
            language='c++',
            extra_compile_args=[
                '-Ofast',
                '-std=c++17',
                '-Wno-unknown-pragmas',
                '-Wno-class-memaccess',
            ],
            extra_link_args=[],
            include_dirs=[
                'src',
                'src/mimalloc/include',
            ]
        ),
    ],
)
